@@ -21,10 +21,12 @@ int main(int argc, char *argv[])
 {
         QApplication app(argc, argv);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	Kdelibs4ConfigMigrator migrate(QStringLiteral("kgeography"));
 	migrate.setConfigFiles(QStringList() << QStringLiteral("kgeographyrc"));
 	migrate.setUiFiles(QStringList() << QStringLiteral("kgeographyui.rc"));
 	migrate.migrate();
+#endif
 	KLocalizedString::setApplicationDomain("kgeography");
 
 	KAboutData about(QStringLiteral("kgeography"), i18n("KGeography"), KGEOGRAPHY_VERSION_STRING, i18n("A Geography learning program"), KAboutLicense::GPL, i18n("© 2004-2005 Albert Astals Cid"), QString(), QStringLiteral("https://userbase.kde.org/KGeography"));
